@@ -2,7 +2,7 @@
 /*
 Plugin Name: CiviCRM
 Description: CiviCRM - Growing and Sustaining Relationships
-Version: 5.18.1
+Version: 5.20.3
 Author: CiviCRM LLC
 Author URI: https://civicrm.org/
 Plugin URI: https://wiki.civicrm.org/confluence/display/CRMDOC/Installing+CiviCRM+for+WordPress
@@ -310,7 +310,10 @@ class CiviCRM_For_WordPress {
 
     // Change option so this action never fires again
     update_option( 'civicrm_activation_in_progress', 'false' );
-
+    if ( ! is_multisite() && !isset($_GET['activate-multi']) && ! CIVICRM_INSTALLED ) {
+      wp_redirect(admin_url("options-general.php?page=civicrm-install"));
+      exit;
+    }
   }
 
 
@@ -361,6 +364,15 @@ class CiviCRM_For_WordPress {
       session_start();
     }
 
+    /*
+     * AJAX calls do not set the 'cms.root' item, so make sure it is set here so
+     * the CiviCRM doesn't fall back on flaky directory traversal code.
+     */
+    global $civicrm_paths;
+    if (empty($civicrm_paths['cms.root']['path'])) {
+      $civicrm_paths['cms.root']['path'] = untrailingslashit(ABSPATH);
+    }
+
     // Get classes and instantiate
     $this->include_files();
 
@@ -559,8 +571,20 @@ class CiviCRM_For_WordPress {
    * Register hooks for the front end.
    *
    * @since 5.6
+   *
+   * @param WP_Query $query The WP_Query instance (passed by reference).
    */
-  public function register_hooks_front_end() {
+  public function register_hooks_front_end( $query ) {
+
+    // Bail if $query is not the main loop.
+    if ( ! $query->is_main_query() ) {
+      return;
+    }
+
+    // Bail if filters are suppressed on this query.
+    if ( true == $query->get( 'suppress_filters' ) ) {
+      return;
+    }
 
     // Prevent multiple calls
     static $alreadyRegistered = FALSE;
